#!/usr/bin/perl
#
# 57wg9u3o  111006  Walter R. Washburn III
# CGI program to collect current IP assignments for home net
#     No interaction, program silently builds log file of IPs assigned.
#
# Files:
#
#       logfile as defined by $LOGFILE
#
# Subs:
#       get_localtime arg: void return: anon hash from sys clock
#
#	    sec => $sec,  zero-led integer
#	    min => $min,  zero-led integer
#	    hour => $hour,  zero-led integer
#	    mday => $mday,  integer of calendar day
#	    mon => $mon,   integer for month of year, Jan = 1
#	    year => $year, CCYY format
#	    wday => $wday, integer Sun = 1
#	    yday => $yday, Julian integer, Jan 1 = 1
#	    isdat => $isdat, 1=DST 0=STD
#	    thismon => $thismon, mmm alpha (e.g. Jan Feb Mar)
#	    thisday => $thisday, ddd alpha (e.g. Mon Tue Wed)
#	    today => "$thismon $mday, $year"
#
#       logger arg: comment string return: 1 on success writing comment to $LOGFILE
#

# Bugs and Fixes, (LIFO)
# 
#
####################################################
# Program Follows
###########################################
use strict;
use warnings;

$|++;   # Flush output on write
print "Content-type: text/html\n\n";


use vars qw( $TRUE $FALSE $VERSION $DEBUG $LOGFILE);

$TRUE = 1;
$FALSE = 0;
$VERSION = "1.0";
$DEBUG = $FALSE;
$LOGFILE = "$0.log";

# Find IP of client invoking program ($NewIP)

my $NewIP = $ENV{'REMOTE_ADDR'};


# Pull last known IP addr from log file ($OldIP)

my $OldIP = "";
open(README, "./target_ip.pl |") or die "Can't run program: $!\n";
while(<README>) {
    $OldIP .= $_;
}
close(README);
chomp $OldIP;

# logger("This is the Old IP: $OldIP \n");

# If $NewIP eq $OldIP terminate
# Otherwise write $NewIP to log & terminate

unless ($NewIP eq $OldIP) {

    logger($NewIP);


}


#####################################################
# Subroutines
###########################################

sub get_localtime {

	my($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdat) =
		localtime(time);

	my $thismon = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec )[$mon];
	my $thisday = qw( Sun Mon Tue Wed Thu Fri Sat )[$wday];

	$wday++;   # converted to base of 1 to be consistent
	$mon++;    # convert to base of 1 (ie Jan is 1 vice 0)
	$yday++;   # convert to Julian day, Jan 1 = 1

	if (length($min) == 1) {
		$min = "0" . $min;
	}
	if (length($hour) == 1) {
		$hour = "0" . $hour;
	} 

	if (length($sec) == 1) {
		$sec = "0" . $sec;
	} 

	$year += ($year < 70) ? 2000 : 1900;
	my $today = "$thismon $mday, $year";

	return {
	    sec => $sec,
	    min => $min,
	    hour => $hour,
	    mday => $mday,
	    mon => $mon,
	    year => $year,
	    wday => $wday,
	    yday => $yday,
	    isdat => $isdat,
	    thismon => $thismon,
	    thisday => $thisday,
	    today => $today,
	};
} # get_localtime


sub logger {
	open(LOG, ">>$LOGFILE")||die "Can't write to $LOGFILE: $!\n";
	my $dates = &get_localtime;
	print LOG "@$dates{'today'} @$dates{'hour'}@$dates{'min'}: $_[0]\n";
	close LOG;
	return 1;
} # logger
 

1;
